BurnInPosition

Enum BurnInPosition 

pub enum BurnInPosition {
    TopLeft,
    TopCenter,
    TopRight,
    BottomLeft,
    BottomCenter,
    BottomRight,
}
Where to anchor the timecode overlay on the frame

Variants



TopLeft

Top-left corner



TopCenter

Top-center



TopRight

Top-right corner



BottomLeft

Bottom-left corner



BottomCenter

Bottom-center



BottomRight

Bottom-right corner

Implementations

Source

impl BurnInPosition

pub fn is_top(&self) -> bool

Returns true if the position is in the top half of the frame

pub fn is_right(&self) -> bool

Returns true if the position is on the right side of the frame