Module drop_frame

Module drop_frame 

Drop-frame timecode calculations for 29.97 fps NTSC.

Drop-frame timecode is a system that keeps timecode aligned with actual elapsed time for 29.97 fps video by “dropping” (skipping) frame numbers 00 and 01 at the start of each minute, except every 10th minute.

Note: “drop frame” refers to dropping frame numbers, not actual video frames.

Structs

DropFrameCalc
Drop-frame timecode calculator for 29.97 fps.
TotalFrameCounter
Frame counter that supports both drop-frame and non-drop-frame modes.