FrameRate

Enum FrameRate 

pub enum FrameRate {
Show 14 variants Fps23976, Fps23976DF, Fps24, Fps25, Fps2997DF, Fps2997NDF, Fps30, Fps47952, Fps47952DF, Fps50, Fps5994, Fps5994DF, Fps60, Fps120,
}
SMPTE timecode frame rates

Variants



Fps23976

23.976 fps (film transferred to NTSC, non-drop frame)



Fps23976DF

23.976 fps drop frame (drops 2 frames every 10 minutes)



Fps24

24 fps (film)



Fps25

25 fps (PAL)



Fps2997DF

29.97 fps (NTSC drop frame)



Fps2997NDF

29.97 fps (NTSC non-drop frame)



Fps30

30 fps



Fps47952

47.952 fps (cinema HFR, pulled-down from 48fps, non-drop frame)



Fps47952DF

47.952 fps drop frame (drops 4 frames every 10 minutes)



Fps50

50 fps (PAL progressive)



Fps5994

59.94 fps (NTSC progressive, non-drop frame)



Fps5994DF

59.94 fps drop frame (drops 4 frames every 10 minutes)



Fps60

60 fps



Fps120

120 fps (high frame rate display / VR)

Implementations

Source

impl FrameRate

pub fn as_float(&self) -> f64

Get the nominal frame rate as a float

pub fn as_rational(&self) -> (u32, u32)

Get the exact frame rate as a rational (numerator, denominator)

pub fn is_drop_frame(&self) -> bool

Check if this is a drop frame rate

pub fn drop_frames_per_minute(&self) -> u64

The number of frames dropped per discontinuity point (every non-10th minute boundary).

For 29.97 DF: 2 frames dropped per minute. For 23.976 DF: 2 frames dropped per minute (scaled from 29.97 × 24/30). For 47.952 DF: 4 frames dropped per minute (scaled from 29.97 × 48/30). For 59.94 DF: 4 frames dropped per minute (scaled from 29.97 × 60/30).

pub fn frames_per_second(&self) -> u32

Get the number of frames per second (rounded)