JamSyncConfig

Struct JamSyncConfig 

pub struct JamSyncConfig {
    pub lock_threshold: usize,
    pub tolerance_frames: u64,
    pub holdover_budget: u64,
}
Configuration for a JamSyncController.

Fields

lock_threshold: usize

Number of consecutive reference frames that must be exactly sequential before the controller transitions from Locking to Locked.

tolerance_frames: u64

Maximum difference in frames between consecutive reference inputs that is still considered “sequential” (for tolerance of jittery inputs).

holdover_budget: u64

Number of output() calls (frames) that can elapse without a reference before the controller transitions from Locked to Holdover.