Module sync_map

Module sync_map 

Timecode sync/offset mapping

Provides TcOffset, TcSyncPoint, and SyncMap for translating frame positions between two timecode domains using linear interpolation.

Structs

SyncMap
A collection of sync points that defines a piecewise-linear mapping between source and target frame domains.
TcOffset
A fixed frame offset with an optional description
TcSyncPoint
A correspondence between a source frame and a target frame