convert_frame_rate

Function convert_frame_rate 

pub fn convert_frame_rate(
    tc: &Timecode,
    target_rate: FrameRate,
    strategy: ConvertStrategy,
) -> Result<ConvertResult, TimecodeError>
Converts a timecode from one frame rate to another.

Errors

Returns an error if the target timecode is invalid (e.g., exceeds 24h).