TcRefPoint

Struct TcRefPoint 

pub struct TcRefPoint {
    pub timecode: Timecode,
    pub position: u64,
}
A known timecode reference point at a specific sample or frame position.

Fields

timecode: Timecode

The timecode value at this reference point.

position: u64

The absolute sample or frame position in the media stream.

Implementations

Source

impl TcRefPoint

pub fn new(timecode: Timecode, position: u64) -> Self

Creates a new timecode reference point.