TcMath

Struct TcMath 

pub struct TcMath;
Stateless utility for timecode mathematical operations.

Example

use oximedia_timecode::tc_math::{TcMath, TcDuration};

let dur = TcDuration::from_hmsf(0, 1, 0, 0, 25); // 1 minute
let mid = TcMath::midpoint_between_durations(&TcDuration::from_frames(0, 25), &dur);
assert_eq!(mid.frames, 750); // 30 seconds at 25fps

Implementations

Source

impl TcMath

pub fn duration_between(a: &Timecode, b: &Timecode) -> TcDuration

Compute the duration between two timecodes (absolute value).

pub fn midpoint( a: &Timecode, b: &Timecode, rate: FrameRate, ) -> Result<Timecode, TimecodeError>

Compute the midpoint timecode between two timecodes.

pub fn offset_by_percentage( tc: &Timecode, duration: &TcDuration, pct: f64, rate: FrameRate, ) -> Result<Timecode, TimecodeError>

Offset a timecode by a percentage of a duration.

pub fn midpoint_between_durations(a: &TcDuration, b: &TcDuration) -> TcDuration

Compute the midpoint between two durations (not anchored to a TOD).

pub fn position_percentage( tc: &Timecode, start: &Timecode, end: &Timecode, ) -> f64

Compute a percentage position of a timecode within a range.

pub fn rate_conversion_factor(from: FrameRate, to: FrameRate) -> f64

Compute the frame rate conversion factor between two rates.

pub fn convert_frame_count(frames: u64, from: FrameRate, to: FrameRate) -> u64

Convert a frame count from one frame rate to another.