pub struct MetadataTimeline { /* private fields */ }Expand description
A timeline of metadata entries keyed by frame number.
Implementations
Sourceimpl MetadataTimeline
impl MetadataTimeline
Sourcepub fn insert(&mut self, frame: u64, meta: TcMetadata)
pub fn insert(&mut self, frame: u64, meta: TcMetadata)
Adds a metadata entry at the given frame.
Sourcepub fn lookup(&self, frame: u64) -> Option<&TcMetadata>
pub fn lookup(&self, frame: u64) -> Option<&TcMetadata>
Finds the metadata entry at or before the given frame.
Sourcepub fn entries(&self) -> &[(u64, TcMetadata)]
pub fn entries(&self) -> &[(u64, TcMetadata)]
Returns all entries as a slice.