pub struct BoundaryChecker { /* private fields */ }Expand description
Checks timecodes against a set of allowed SMPTE ranges.
Implementations
Sourceimpl BoundaryChecker
impl BoundaryChecker
Sourcepub fn add_range(&mut self, range: SmpteRange)
pub fn add_range(&mut self, range: SmpteRange)
Add an allowed range.
Sourcepub fn from_ranges(ranges: &[SmpteRange]) -> Self
pub fn from_ranges(ranges: &[SmpteRange]) -> Self
Create a checker from a slice of ranges.
Sourcepub fn is_allowed(&self, tc: &Timecode) -> bool
pub fn is_allowed(&self, tc: &Timecode) -> bool
Check whether a timecode is inside any of the allowed ranges.
Sourcepub fn matching_ranges(&self, tc: &Timecode) -> usize
pub fn matching_ranges(&self, tc: &Timecode) -> usize
Return how many allowed ranges contain the given timecode.