pub fn apply_frame_offset(
cues: &[SubtitleCue],
offset: i64,
rate: FrameRate,
) -> Result<Vec<SubtitleCue>, TimecodeError>Expand description
Offset correction: shift all cues by a fixed number of frames.
pub fn apply_frame_offset(
cues: &[SubtitleCue],
offset: i64,
rate: FrameRate,
) -> Result<Vec<SubtitleCue>, TimecodeError>Offset correction: shift all cues by a fixed number of frames.