Linear Timecode (LTC) reading and writing
LTC encodes timecode as an audio signal using biphase mark code (BMC). The audio signal contains 80 bits per frame:
- 64 bits for timecode and user data
- 16 bits for sync word (0x3FFD)
Biphase Mark Code
- Bit 0: One transition in the middle of the bit cell
- Bit 1: Two transitions (at the beginning and middle)
- Frequencies: ~1920 Hz (bit 0 at 30fps) to ~2400 Hz (bit 1 at 30fps)
Signal Characteristics
- Typically recorded at line level (-10 dBV to +4 dBu)
- Can be read in forward or reverse
- Can be read at varying speeds (0.1x to 10x nominal)
Modules
- decoder
- LTC Decoder - Biphase Mark Code decoding from audio
- encoder
- LTC Encoder - Biphase Mark Code encoding to audio
Structs
- LtcReader
- LTC reader
- LtcReader
Config - LTC reader configuration
- LtcWriter
- LTC writer
- LtcWriter
Config - LTC writer configuration