pub struct TcRefPoint {
pub timecode: Timecode,
pub position: u64,
}Expand description
A known timecode reference point at a specific sample or frame position.
Fields
timecode: TimecodeThe timecode value at this reference point.
position: u64The absolute sample or frame position in the media stream.
Implementations