pub struct TcMetadata {
pub timecode: Timecode,
pub frame_rate: FrameRate,
pub source: TimecodeSource,
pub reel: Option<ReelId>,
pub record_date: Option<RecordDate>,
pub user_bits: Option<UserBitsPayload>,
pub tags: HashMap<String, String>,
pub scene: Option<String>,
pub take: Option<u32>,
}Expand description
Comprehensive timecode metadata block.
Bundles a timecode with all associated metadata such as source, reel, date, user bits, and custom key-value tags.
Fields
timecode: TimecodeThe timecode value
frame_rate: FrameRateFrame rate used for the timecode
source: TimecodeSourceSource of the timecode
reel: Option<ReelId>Optional reel identifier
record_date: Option<RecordDate>Optional recording date
user_bits: Option<UserBitsPayload>User bits payload
Arbitrary string key-value tags
scene: Option<String>Scene label
take: Option<u32>Take number
Implementations
Sourceimpl TcMetadata
impl TcMetadata
Sourcepub fn new(
timecode: Timecode,
frame_rate: FrameRate,
source: TimecodeSource,
) -> Self
pub fn new( timecode: Timecode, frame_rate: FrameRate, source: TimecodeSource, ) -> Self
Creates new metadata for a timecode.
Sourcepub fn with_record_date(self, date: RecordDate) -> Self
pub fn with_record_date(self, date: RecordDate) -> Self
Sets the recording date.
Sourcepub fn with_user_bits(self, ub: UserBitsPayload) -> Self
pub fn with_user_bits(self, ub: UserBitsPayload) -> Self
Sets the user bits.
Sourcepub fn with_tag(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn with_tag(self, key: impl Into<String>, value: impl Into<String>) -> Self
Adds a custom tag.
Sourcepub fn with_scene(self, scene: impl Into<String>) -> Self
pub fn with_scene(self, scene: impl Into<String>) -> Self
Sets the scene label.