pub struct TimecodeSequence { /* private fields */ }Expand description
An ordered sequence of TimecodeRun entries representing a playlist or
edit decision list.
Implementations
Sourceimpl TimecodeSequence
impl TimecodeSequence
Sourcepub fn push(&mut self, run: TimecodeRun)
pub fn push(&mut self, run: TimecodeRun)
Append a run to the sequence.
Sourcepub fn total_frames(&self) -> u64
pub fn total_frames(&self) -> u64
Total number of frames across all runs.
Sourcepub fn get(&self, index: usize) -> Option<&TimecodeRun>
pub fn get(&self, index: usize) -> Option<&TimecodeRun>
Get a run by index.
Sourcepub fn is_contiguous(&self, a_idx: usize, b_idx: usize) -> bool
pub fn is_contiguous(&self, a_idx: usize, b_idx: usize) -> bool
Check whether two adjacent runs are contiguous (end of run N + 1 == start of run N+1).
Sourcepub fn total_duration_secs(&self) -> f64
pub fn total_duration_secs(&self) -> f64
Return the total duration (seconds) of the whole sequence.
Sourcepub fn find_run_at_offset(&self, offset: u64) -> Option<(usize, u64)>
pub fn find_run_at_offset(&self, offset: u64) -> Option<(usize, u64)>
Find the run containing a given absolute frame offset into the sequence.
Returns (run_index, offset_within_run).
Sourcepub fn iter(&self) -> Iter<'_, TimecodeRun>
pub fn iter(&self) -> Iter<'_, TimecodeRun>
Return an iterator over all runs.
Sourcepub fn detect_gaps(&self) -> Vec<(usize, i64)>
pub fn detect_gaps(&self) -> Vec<(usize, i64)>
Detect gaps between adjacent runs and return the gap durations in frames.