pub enum ValidationRule {
HoursInRange,
MinutesInRange,
SecondsInRange,
FramesInRange,
DropFramePositions,
WithinRange,
}Expand description
A single validation rule that can be applied to a timecode.
Variants
HoursInRange
Hours must be in 0–23.
MinutesInRange
Minutes must be in 0–59.
SecondsInRange
Seconds must be in 0–59.
FramesInRange
Frame count must be in 0–(fps-1).
DropFramePositions
Frames 0 and 1 are illegal at the start of non-tenth minutes (DF only).
WithinRange
Timecode must lie within an explicit allowed range [start, end].