pub struct TimecodeValidator { /* private fields */ }Expand description
Validates timecodes against a configurable set of rules.
Example
use oximedia_timecode::{Timecode, FrameRate};
use oximedia_timecode::tc_validator::{TimecodeValidator, ValidatorConfig};
let validator = TimecodeValidator::new(ValidatorConfig::default());
let tc = Timecode::new(1, 0, 0, 0, FrameRate::Fps25).unwrap();
assert!(validator.validate(&tc).is_empty());Implementations
Sourceimpl TimecodeValidator
impl TimecodeValidator
Sourcepub fn new(config: ValidatorConfig) -> Self
pub fn new(config: ValidatorConfig) -> Self
Create a new validator with the given configuration.
Sourcepub fn default_validator() -> Self
pub fn default_validator() -> Self
Create a validator with default rules.
Sourcepub fn validate(&self, tc: &Timecode) -> Vec<TcViolation>
pub fn validate(&self, tc: &Timecode) -> Vec<TcViolation>
Validate a Timecode and return all violations found.
An empty Vec means the timecode is valid under the configured rules.
Sourcepub fn validate_range(
&self,
timecodes: &[Timecode],
) -> Vec<(usize, TcViolation)>
pub fn validate_range( &self, timecodes: &[Timecode], ) -> Vec<(usize, TcViolation)>
Validate a range of consecutive timecodes for continuity. Returns violations for any timecode in the slice that fails validation.